import type { Meta, StoryObj } from '@storybook/react';
import Button from './Button';

const meta: Meta<typeof Button> = {
  title: 'Basic/Button',
  component: Button,
  tags: ['autodocs'],
};

export default meta;

type Story = StoryObj<typeof meta>;

const Template = () => {
  return (
    <div>
      <h6 className="mb-2 font-semibold">Size</h6>
      <div className="flex gap-5 mb-4 flex-wrap items-center">
        <Button size="sm">
          Small button
        </Button>
        <Button >Medium button</Button>
        <Button href="/" size="sm">
          Small Anchor
        </Button>
        <Button href="/">
          Medium Anchor
        </Button>
        <Button size="sm" >
          Small Outline
        </Button>
        <Button  >
          Medium Outline
        </Button>
      </div>
      <h6 className="mb-2 font-semibold">Loading</h6>
      <div className="flex gap-5 mb-4 flex-wrap items-center">
        <Button size="sm" loading>
          Small button
        </Button>
        <Button loading>
          Medium button
        </Button>
        <Button href="/" size="sm" loading>
          Small Anchor
        </Button>
        <Button href="/" loading>
          Medium Anchor
        </Button>
        <Button size="sm" loading >
          Small Outline
        </Button>
        <Button loading >
          Medium Outline
        </Button>
      </div>
      <h6 className="mb-2 font-semibold">Disabled</h6>
      <div className="flex gap-5 mb-4 flex-wrap items-center">
        <Button size="sm" disabled>
          Small button
        </Button>
        <Button disabled>
          Medium button
        </Button>
        <Button size="sm" disabled >
          Small Outline
        </Button>
        <Button disabled >
          Medium Outline
        </Button>
      </div>
      <h6 className="mb-2 font-semibold">Disabled & Loading</h6>
      <div className="flex gap-5 mb-4 flex-wrap items-center">
        <Button size="sm" loading disabled>
          Small button
        </Button>
        <Button loading disabled>
          Medium button
        </Button>
        <Button size="sm" disabled loading >
          Small Outline
        </Button>
        <Button disabled loading >
          Medium Outline
        </Button>
      </div>
      <h6 className="mb-2 font-semibold">Multiline</h6>
      <div className="flex gap-5 mb-4 flex-wrap items-center">
        <Button size="sm">
          Lorem ipsum dolor sit <br /> amet consectetur adipisicing elit. <br />{' '}
          Quas exercitationem unde voluptate iure dolore laudantium.
        </Button>
        <Button >
          Lorem ipsum dolor sit amet consectetur adipisicing elit. <br /> Quas
          exercitationem unde voluptate iure dolore laudantium.
        </Button>
      </div>
      <br />
      <div className="flex gap-5 mb-4 flex-wrap items-center">
        <Button size="sm" loading>
          Lorem ipsum dolor sit <br /> amet consectetur adipisicing elit. <br />{' '}
          Quas exercitationem unde voluptate iure dolore laudantium.
        </Button>
        <Button loading>
          Lorem ipsum dolor sit amet consectetur adipisicing elit. <br /> Quas
          exercitationem unde voluptate iure dolore laudantium.
        </Button>
      </div>
      <h6 className="mb-2 font-semibold">Block</h6>
      <div className="flex flex-col gap-5">
        <Button size="sm" >
          Small button
        </Button>
        <Button  >
          Medium button
        </Button>
        <Button size="sm" loading>
          Small button
        </Button>
        <Button loading>
          Medium button
        </Button>
        <Button size="sm" loading disabled>
          Small button
        </Button>
        <Button loading disabled>
          Medium button
        </Button>
      </div>
    </div>
  );
};

export const primary: Story = {
  render: () => (
    <Template />
  )
}