"use client"
import React from "react";
import { useState, useEffect } from "react";
import style from "./todoapp.module.css"
import Heading from "@/components/base/Heading/Heading";
import List from "@/components/layout/List/List";
import FormComponent from "@/components/Top-Level/Form/FormComponent";
import { TodoListItems } from "@/Types/todoTypes";
import AddTask, { UpdateTask, DeleteTask } from "@/lib/TodoApi";
import getall from "@/lib/getall";

const Todo = () => {
    const [refresh, setrefresh] = useState(false)
    const [TodoList, setTodoList] = useState({
        isError: false,
        isLoading: true,
        data: []
    })
    useEffect(() => {
        (async () => {
            setTodoList(
                {
                    ...TodoList,
                    isLoading: true,
                }
            )

            const data = await getall();
            if (data) {
                setTodoList({
                    isError: false,
                    isLoading: false,
                    data
                })
            } else {
                setTodoList({
                    ...TodoList,
                    isLoading: false,
                    isError: true,
                })
            }
        })()
    }, [refresh])

    const handleDelete = async (id: number) => {
        const result = await DeleteTask(id)
        if (result) {
            setrefresh(!refresh)
        }
    }
    const handlePost = async (task: string) => {
        const result = await AddTask(task)
        if (result) {
            setrefresh(!refresh)
        }
    }

    return (
        <div className={style.container}>
            <div className={style.todoWrapper}>
                {TodoList.isLoading && <div className={style.loading} />}
                {TodoList.isError && <h2 className={style.notFound}>Something went wrong</h2>}
                {
                    !TodoList.isError && !TodoList.isLoading && TodoList.data &&
                    (
                        <React.Fragment>
                            <Heading count={TodoList.data.length} />
                            {
                                TodoList.data.length !== 0 &&
                                <List data={TodoList.data} onDelete={handleDelete} updateTask={UpdateTask} />
                            }
                            <FormComponent onPost={handlePost} />
                        </React.Fragment>
                    )
                }
            </div>
        </div>

    );
}

export default Todo;